Package: recordmydesktop
Version: 0.3.8.1+svn602
Severity: minor
Dear Maintainer,
I got an error message saying that the program
"Could not open out.ogv for writting!"
Decided to send a patch to fix this spelling and found 'writing' spelled
'writting' repeatedly. Similarly 'process' spelled 'proccess'.
Fixed all the instances of those in the package.
patch attached.
-- System Information:
Debian Release: 8.2
APT prefers stable-updates
APT policy: (500, 'stable-updates'), (500, 'stable')
Architecture: amd64 (x86_64)
Kernel: Linux 3.16.0-4-amd64 (SMP w/8 CPU cores)
Locale: LANG=en_GB.UTF-8, LC_CTYPE=en_GB.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash
Init: systemd (via /run/systemd/system)
Versions of packages recordmydesktop depends on:
ii libasound2 1.0.28-1
ii libc6 2.19-18+deb8u1
ii libice6 2:1.0.9-1+b1
pn libjack-jackd2-0 | libjack-0.116 <none>
ii libogg0 1.3.2-1
ii libpopt0 1.16-10
ii libsm6 2:1.2.2-1+b1
pn libtheora0 <none>
ii libvorbis0a 1.3.4-2
ii libvorbisenc2 1.3.4-2
ii libvorbisfile3 1.3.4-2
ii libx11-6 2:1.6.2-3
ii libxdamage1 1:1.1.4-2+b1
ii libxext6 2:1.3.3-1
ii libxfixes3 1:5.0.1-2+b2
ii zlib1g 1:1.2.8.dfsg-2+b1
recordmydesktop recommends no packages.
recordmydesktop suggests no packages.
diff -u recordmydesktop-0.3.8.1+svn602/debian/changelog recordmydesktop-0.3.8.1+svn602/debian/changelog
diff -u recordmydesktop-0.3.8.1+svn602/debian/control recordmydesktop-0.3.8.1+svn602/debian/control
--- recordmydesktop-0.3.8.1+svn602/debian/control
+++ recordmydesktop-0.3.8.1+svn602/debian/control
@@ -14,3 +14,3 @@
The application produces an ogg-encapsulated theora-vorbis file.
- recordMyDesktop tries to be as unobstrusive as possible by proccessing only
+ recordMyDesktop tries to be as unobstrusive as possible by processing only
regions of the screen that have changed
only in patch2:
unchanged:
only in patch2:
unchanged:
only in patch2:
unchanged:
--- recordmydesktop-0.3.8.1+svn602.orig/doc/recordmydesktop.1
+++ recordmydesktop-0.3.8.1+svn602/doc/recordmydesktop.1
@@ -161,9 +161,9 @@
.br
11 Improper window specification.
.br
-12 Cannot attach shared memory to proccess.
+12 Cannot attach shared memory to process.
.br
-13 Cannot open file for writting.
+13 Cannot open file for writing.
.br
14 Cannot load the Jack library (
.B
only in patch2:
unchanged:
--- recordmydesktop-0.3.8.1+svn602.orig/src/rmd_cache.h
+++ recordmydesktop-0.3.8.1+svn602/src/rmd_cache.h
@@ -36,7 +36,7 @@
/**
-* Change file pointer to a new file while writting
+* Change file pointer to a new file while writing
* (file name is incremented with CacheFileN)
*
* \param name base file name
only in patch2:
unchanged:
--- recordmydesktop-0.3.8.1+svn602.orig/src/rmd_cache_frame.c
+++ recordmydesktop-0.3.8.1+svn602/src/rmd_cache_frame.c
@@ -258,7 +258,7 @@
//clean exit.
//In either case data will be preserved so if
//space is freed the recording
- //can be proccessed later.
+ //can be processed later.
}
total_bytes += nbytes;
nth_cache++;
only in patch2:
unchanged:
--- recordmydesktop-0.3.8.1+svn602.orig/src/rmd_capture_sound.c
+++ recordmydesktop-0.3.8.1+svn602/src/rmd_capture_sound.c
@@ -162,7 +162,7 @@
pthread_mutex_unlock(&pdata->sound_buffer_mutex);
- //signal that there are data to be proccessed
+ //signal that there are data to be processed
pthread_mutex_lock(&pdata->snd_buff_ready_mutex);
pthread_cond_signal(&pdata->sound_data_read);
pthread_mutex_unlock(&pdata->snd_buff_ready_mutex);
only in patch2:
unchanged:
--- recordmydesktop-0.3.8.1+svn602.orig/src/rmd_get_frame.c
+++ recordmydesktop-0.3.8.1+svn602/src/rmd_get_frame.c
@@ -244,7 +244,7 @@
NULL,0);
(*shminfo).readOnly = False;
if(!XShmAttach(pdata->dpy,shminfo)){
- fprintf(stderr,"Failed to attach shared memory to proccess.\n");
+ fprintf(stderr,"Failed to attach shared memory to process.\n");
return 12;
}
XShmGetImage(pdata->dpy,
only in patch2:
unchanged:
--- recordmydesktop-0.3.8.1+svn602.orig/src/rmd_init_encoder.c
+++ recordmydesktop-0.3.8.1+svn602/src/rmd_init_encoder.c
@@ -130,7 +130,7 @@
enc_data_t->fp=fopen((pdata)->args.filename,"w");
if(enc_data_t->fp==NULL){
- fprintf(stderr,"Cannot open file %s for writting!\n",
+ fprintf(stderr,"Cannot open file %s for writing!\n",
(pdata)->args.filename);
exit(13);
}
only in patch2:
unchanged:
--- recordmydesktop-0.3.8.1+svn602.orig/src/rmd_load_cache.c
+++ recordmydesktop-0.3.8.1+svn602/src/rmd_load_cache.c
@@ -165,7 +165,7 @@
audio_end=0,
extra_frames=0,//total number of duplicated frames
missing_frames=0,//if this is found >0 current run will not load
- //a frame but it will proccess the previous
+ //a frame but it will process the previous
thread_exit=0,//0 success, -1 couldn't find files,1 couldn't remove
blocknum_x=pdata->enc_data->yuv.y_width/Y_UNIT_WIDTH,
blocknum_y=pdata->enc_data->yuv.y_height/Y_UNIT_WIDTH,
@@ -212,7 +212,7 @@
}
}
- //this will be used now to define if we proccess audio or video
+ //this will be used now to define if we process audio or video
//on any given loop.
pdata->avd=0;
//If sound finishes first,we go on with the video.
only in patch2:
unchanged:
--- recordmydesktop-0.3.8.1+svn602.orig/src/rmd_types.h
+++ recordmydesktop-0.3.8.1+svn602/src/rmd_types.h
@@ -67,7 +67,7 @@
typedef u_int32_t cmp_int_t;
#endif
//type of pixel proccessing for the Cb,Cr planes
//when converting from full rgb to 4:2:2 Ycbcr
enum{
__PXL_DISCARD, //only select 1 pixel in every block of four
@@ -156,7 +156,7 @@
}ProgArgs;
//this struct holds anything related to encoding AND
-//writting out to file.
+//writing out to file.
typedef struct _EncData{
ogg_stream_state m_ogg_ts; //theora
ogg_stream_state m_ogg_vs; //vorbis
@@ -192,7 +192,7 @@
*projname, //This is the name of the folder that
//will hold the project.
//It is rMD-session-%d where %d is the pid
- //of the current proccess.
+ //of the current process.
//This way, running two instances
//will not create problems
//and also, a frontend can identify
@@ -282,10 +282,10 @@
//whenever it's time to get a screenshot
pause_cond, //this is blocks execution,
//when program is paused
- sound_data_read, //a buffer is ready for proccessing
+ sound_data_read, //a buffer is ready for processing
image_buffer_ready, //image encoding finished
theora_lib_clean, //the flush_ogg thread cannot
- //procceed to creating last
+ //proceed to creating last
vorbis_lib_clean; //packages until these two libs
//are no longer used, by other threads
/**Buffers,Flags and other vars*/
@@ -67,7 +67,7 @@
typedef u_int32_t cmp_int_t;
#endif
-//type of pixel proccessing for the Cb,Cr planes
+//type of pixel processing for the Cb,Cr planes
//when converting from full rgb to 4:2:2 Ycbcr
enum{